@@ -225,7 +225,7 @@ bool DeclarationBuilder::isBaseMethodRedeclaration(const IdentifierPair &ids, Cl
             {
                 if (dec->isFunctionDeclaration()) {
                     ClassMethodDeclaration* func = dynamic_cast<ClassMethodDeclaration*>(dec);
-                    if (!func) {
+                    if (!func || !wasEncountered(func)) {
                         continue;
                     }
                     // we cannot redeclare final classes ever
@@ -264,7 +264,7 @@ void DeclarationBuilder::visitClassStatement(ClassStatementAst *node)
                 DUChainWriteLocker lock(DUChain::lock());
                 foreach(Declaration * dec, currentContext()->findLocalDeclarations(ids.second.first(), startPos(node->methodName)))
                 {
-                    if (dec->isFunctionDeclaration()) {
+                    if (wasEncountered(dec) && dec->isFunctionDeclaration()) {
                         reportRedeclarationError(dec, node->methodName);
                         localError = true;
                         break;
@@ -383,7 +383,7 @@ void DeclarationBuilder::visitClassVariable(ClassVariableAst *node)
         Q_ASSERT(currentContext()->type() == DUContext::Class);
         foreach(Declaration * dec, currentContext()->findLocalDeclarations(name.first(), startPos(node)))
         {
-            if (!dec->isFunctionDeclaration() && ! dec->abstractType()->modifiers() & AbstractType::ConstModifier) {
+            if (wasEncountered(dec) && !dec->isFunctionDeclaration() && ! dec->abstractType()->modifiers() & AbstractType::ConstModifier) {
                 reportRedeclarationError(dec, node);
                 break;
             }
@@ -484,7 +484,7 @@ void DeclarationBuilder::visitConstantDeclaration(ConstantDeclarationAst *node)
         DUChainWriteLocker lock(DUChain::lock());
         foreach(Declaration * dec, currentContext()->findLocalDeclarations(identifierForNode(node->identifier).first(), startPos(node->identifier)))
         {
-            if (!dec->isFunctionDeclaration() && dec->abstractType()->modifiers() & AbstractType::ConstModifier) {
+            if (wasEncountered(dec) && !dec->isFunctionDeclaration() && dec->abstractType()->modifiers() & AbstractType::ConstModifier) {
                 reportRedeclarationError(dec, node->identifier);
                 break;
             }
@@ -624,7 +624,7 @@ bool DeclarationBuilder::isGlobalRedeclaration(const QualifiedIdentifier &identi
     DUChainWriteLocker lock(DUChain::lock());
     QList<Declaration*> declarations = currentContext()->topContext()->findDeclarations( identifier, startPos(node) );
     foreach(Declaration* dec, declarations) {
-        if (isMatch(dec, type)) {
+        if (wasEncountered(dec) && isMatch(dec, type)) {
             reportRedeclarationError(dec, node);
             return true;
         }
@@ -710,6 +710,9 @@ void DeclarationBuilder::declareVariable(DUContext* parentCtx, AbstractType::Ptr
     }
 
     DUChainWriteLocker lock(DUChain::lock());
+
+    const RangeInRevision newRange = editorFindRange(node, node);
+
     // check if this variable is already declared
     {
         QList< Declaration* > decs = parentCtx->findDeclarations(identifier.first(), startPos(node), 0, DUContext::DontSearchInParent);
@@ -718,7 +721,12 @@ void DeclarationBuilder::declareVariable(DUContext* parentCtx, AbstractType::Ptr
             while ( true ) {
                 // we expect that the list of declarations has the newest declaration at back
                 if ( dynamic_cast<VariableDeclaration*>( *it ) ) {
-                    encounter(*it);
+                    if (!wasEncountered(*it)) {
+                        encounter(*it);
+                        // force new range https://bugs.kde.org/show_bug.cgi?id=262189,
+                        // might be wrong when we had syntax errors in there before
+                        (*it)->setRange(newRange);
+                    }
                     if ( (*it)->abstractType() && !(*it)->abstractType()->equals(type.unsafeData()) ) {
                         // if it's currently mixed and we now get something more definite, use that instead
                         if ( ReferenceType::Ptr rType = ReferenceType::Ptr::dynamicCast((*it)->abstractType()) ) {
@@ -772,8 +780,6 @@ void DeclarationBuilder::declareVariable(DUContext* parentCtx, AbstractType::Ptr
         }
     }
 
-    RangeInRevision newRange = editorFindRange(node, node);
-
     VariableDeclaration *dec = openDefinition<VariableDeclaration>(identifier, newRange);
     dec->setKind(Declaration::Instance);
     if (!m_lastTopStatementComment.isEmpty()) {
@@ -783,7 +789,7 @@ void DeclarationBuilder::declareVariable(DUContext* parentCtx, AbstractType::Ptr
         }
     }
     //own closeDeclaration() that doesn't use lastType()
-    currentDeclaration()->setType(type);
+    dec->setType(type);
     eventuallyAssignInternalContext();
     DeclarationBuilderBase::closeDeclaration();
 }
@@ -1158,7 +1164,10 @@ void DeclarationBuilder::visitUseNamespace(UseNamespaceAst* node)
                                                                                 m_editor->findRange(idNode));
     {
         ///TODO: case insensitive!
-        decl->setImportIdentifier( identifierForNamespace(node->identifier, m_editor) );
+        QualifiedIdentifier qid = identifierForNamespace(node->identifier, m_editor);
+        ///TODO: find out why this must be done (see mail to kdevelop-devel on jan 18th 2011)
+        qid.setExplicitlyGlobal( false );
+        decl->setImportIdentifier( qid );
         decl->setPrettyName( id.first );
         decl->setKind(Declaration::NamespaceAlias);
     }
